#!/usr/bin/env python
#
# @package      hubzero-submit-monitors
# @file         monitorJobU.py
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2004-2015 HUBzero Foundation, LLC.
# @license      http://opensource.org/licenses/MIT MIT
#
# Copyright (c) 2004-2015 HUBzero Foundation, LLC.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#
# ----------------------------------------------------------------------
#  monitorJobU.py
#
#  script which queries monitorJob.py for active job(s) belonging to a user
#
import os
import time
import logging

from hubzero.submit.DaemonsInfo      import DaemonsInfo
from hubzero.submit.RemoteJobMonitor import RemoteJobMonitor

CONFIGURATIONDIRECTORY   = os.path.join(os.sep,'etc','submit')
DAEMONSCONFIGURATIONFILE = 'daemons.conf'

APPLICATIONLOGGER = logging.getLogger('') 

def openLogger():
   class EmptyFilter(logging.Filter):
      """
      This is a filter which rejects empty messages

      """

      def filter(self,record):
         if record.getMessage() == "":
            emptyRecord = True
         else:
            emptyRecord = False

         return(not emptyRecord)

   APPLICATIONLOGGER.setLevel(logging.DEBUG)

   logHandler = logging.StreamHandler()

   emptyFilter = EmptyFilter()
   logHandler.addFilter(emptyFilter)

   logFormatter = logging.Formatter('%(asctime)s %(message)s','[%a %b %d %H:%M:%S %Y]')
   logHandler.setFormatter(logFormatter)
   APPLICATIONLOGGER.addHandler(logHandler)


def monitorJobU(listenURI):
   """Report user jobs"""
   hubUserId = os.getuid()

   remoteJobMonitor = RemoteJobMonitor(listenURI)

   reportTime,reportedJobs = remoteJobMonitor.queryUserActiveJobStatus(hubUserId)
   if len(reportedJobs) > 0:
      print "Report time %s" % (time.ctime(reportTime))

      maximumRunNameLength = 0
      localJobIds = reportedJobs.keys()
      for localJobId in localJobIds:
         instanceIds = reportedJobs[localJobId].keys()
         for instanceId in instanceIds:
            runName,jobQueue,jobSite,jobStatus,jobStage = reportedJobs[localJobId][instanceId]
            maximumRunNameLength = max(maximumRunNameLength,len(runName))

      localJobIds = reportedJobs.keys()
      localJobIds.sort()
      for localJobId in localJobIds:
         instanceIds = reportedJobs[localJobId].keys()
         instanceIds.sort()
         for instanceId in instanceIds:
            runName,jobQueue,jobSite,jobStatus,jobStage = reportedJobs[localJobId][instanceId]
            if jobQueue != '?':
               queueSite = jobQueue + '@' + jobSite
            else:
               queueSite = jobSite
            print "%-*s  %12s  %8s  %20s  %15s  %s" % (maximumRunNameLength,runName, \
                                                       localJobId,instanceId,jobStatus,jobStage,queueSite)
   else:
      print "Current time %s" % (time.ctime())
      print "No jobs currently being processed"

   del reportedJobs


if __name__ == '__main__':
   openLogger()

   configFilePath = os.path.join(CONFIGURATIONDIRECTORY,DAEMONSCONFIGURATIONFILE)
   daemonsInfo    = DaemonsInfo(configFilePath)
   listenURI      = daemonsInfo.getDaemonListenURI('jobMonitor','tcp')

   monitorJobU(listenURI)


